<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>Re&amp;gião:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>Configurações de&amp;talhadas</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Números:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>&amp;Hora:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>Mo&amp;eda:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Unidades de medida:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>Verificação e organização:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Números:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Hora:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="278"/>
        <source>Currency:</source>
        <translation>Moeda:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="298"/>
        <source>Measurement Units:</source>
        <translation>Unidades de medida:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="126"/>
        <source>No change</source>
        <translation>Sem alterações</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="313"/>
        <source>Format Settings Changed</source>
        <translation>Configurações de formato alteradas</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="314"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Você deseja salvar estas configurações? Elas surtirão efeito na próxima vez que você iniciar a sessão.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="417"/>
        <source>Imperial UK</source>
        <translation>Imperial (Reino Unido)</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="421"/>
        <source>Imperial US</source>
        <translation>Imperial (EUA)</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="425"/>
        <source>Metric</source>
        <translation>Métrica</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>Configurações de Localização do LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Configurações de Localização</translation>
    </message>
</context>
</TS>
